@@ -28,7 +28,7 @@ class ControllerRevision(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.revision:
                 raise MissingRequiredArgumentError(argument="revision")
             self.res.update({"revision": self.revision})
