@@ -46,10 +46,8 @@ class Image(NamespacedResource):
         super().to_dict()
 
         if not self.kind_dict and not self.yaml_file:
-            if not all([
-                self.image,
-            ]):
-                raise MissingRequiredArgumentError(argument="image")
+            if not self.image:
+                raise MissingRequiredArgumentError(argument="self.image")
 
             self.res["spec"] = {}
             _spec = self.res["spec"]
@@ -61,3 +59,5 @@ class Image(NamespacedResource):
 
             if self.service_account_name:
                 _spec["serviceAccountName"] = self.service_account_name
+
+    # End of generated code
