@@ -41,7 +41,7 @@ class VirtualMachineClone(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.source_name:
                 raise MissingRequiredArgumentError(argument="source_name")
             spec = self.res.setdefault("spec", {})
